package com.glxp.api.admin.controller.basic;

import com.github.pagehelper.PageInfo;
import com.glxp.api.admin.entity.basic.BussinessChangeTypeEntity;
import com.glxp.api.admin.entity.basic.BussinessLocalTypeEntity;
import com.glxp.api.admin.entity.business.StockOrderEntity;
import com.glxp.api.admin.req.basic.BussinessLocalTypeFilterRequest;
import com.glxp.api.admin.req.business.StockOrderFilterRequest;
import com.glxp.api.admin.req.inout.DeleteRequest;
import com.glxp.api.admin.res.PageSimpleResponse;
import com.glxp.api.admin.service.auth.AuthAdminService;
import com.glxp.api.admin.service.basic.BussinessChangeTypeService;
import com.glxp.api.admin.service.basic.BussinessLocalTypeService;
import com.glxp.api.admin.service.basic.BussinessTypeService;
import com.glxp.api.admin.service.business.StockOrderService;
import com.glxp.api.admin.util.CustomUtil;
import com.glxp.api.common.enums.ResultEnum;
import com.glxp.api.common.res.BaseResponse;
import com.glxp.api.common.util.ResultVOUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@RestController
public class BussinessLocalTypeController {

    @Resource
    private BussinessChangeTypeService bussinessChangeTypeService;
    @Resource
    private AuthAdminService authAdminService;
    @Resource
    private BussinessTypeService bussinessTypeService;
    @Resource
    private StockOrderService stockOrderService;
    @Resource
    private BussinessLocalTypeService bussinessLocalTypeService;

    @GetMapping("/udiwms/localBusType/filterJoin")
    public BaseResponse filterJoin(BussinessLocalTypeFilterRequest bussinessTypeFilterRequest,
                                   BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<BussinessLocalTypeEntity> bussinessTypeEntities;
        bussinessTypeEntities = bussinessLocalTypeService.filterJoin(
                bussinessTypeFilterRequest);
        PageInfo<BussinessLocalTypeEntity> pageInfo;
        pageInfo = new PageInfo<>(bussinessTypeEntities);
        PageSimpleResponse<BussinessLocalTypeEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(bussinessTypeEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @GetMapping("/udiwms/localBusType/filter")
    public BaseResponse filterBussinessType(BussinessLocalTypeFilterRequest bussinessTypeFilterRequest,
                                            BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<BussinessLocalTypeEntity> bussinessTypeEntities = null;
//        if (bussinessTypeFilterRequest.getIsFilterBind()) {
//            bussinessTypeEntities = bussinessLocalTypeService.filterUnBind(bussinessTypeFilterRequest);
//        } else {
        bussinessTypeEntities = bussinessLocalTypeService.filterList(bussinessTypeFilterRequest);
//        }


        PageInfo<BussinessLocalTypeEntity> pageInfo;
        pageInfo = new PageInfo<>(bussinessTypeEntities);
        PageSimpleResponse<BussinessLocalTypeEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(bussinessTypeEntities);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @PostMapping("/udiwms/localBusType/delete")
    public BaseResponse deleteBussinessType(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String id = deleteRequest.getId();
        BussinessLocalTypeEntity bussinessLocalTypeEntity = bussinessLocalTypeService.selectById(id);
        BussinessLocalTypeFilterRequest bussinessTypeFilterRequest = new BussinessLocalTypeFilterRequest();
        bussinessTypeFilterRequest.setAction(bussinessLocalTypeEntity.getAction());
        List<BussinessLocalTypeEntity> bussinessLocalTypeEntities = bussinessLocalTypeService.filterJoin(bussinessTypeFilterRequest);
        if (bussinessLocalTypeEntities != null && bussinessLocalTypeEntities.size() > 0) {
            return ResultVOUtils.error(500, "该业务单据类型已被扫码单据类型绑定，无法删除！");
        } else {
            StockOrderFilterRequest stockOrderFilterRequest = new StockOrderFilterRequest();
            stockOrderFilterRequest.setBillType(bussinessLocalTypeEntity.getAction());
            StockOrderEntity stockOrderEntity = stockOrderService.findOne(stockOrderFilterRequest);
            if (stockOrderEntity != null) {
                return ResultVOUtils.error(500, "已存在该类型业务单据，无法删除！");
            }
        }

        BussinessChangeTypeEntity bussinessChangeTypeEntity = bussinessChangeTypeService.findFirstByAction(bussinessLocalTypeEntity.getAction());
        if (bussinessChangeTypeEntity != null && bussinessChangeTypeEntity.getScAction() != null) {
            return ResultVOUtils.error(500, "该业务单据类型已绑定流转单据类型，无法删除！");
        }
        bussinessLocalTypeService.deleteById(id);
        return ResultVOUtils.success("删除成功");
    }

    @PostMapping("/udiwms/localBusType/update")
    public BaseResponse updateBussinessType(@RequestBody BussinessLocalTypeEntity bussinessTypeEntity,
                                            BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (bussinessTypeEntity != null) {
            bussinessLocalTypeService.updateBusLocalType(bussinessTypeEntity);
        } else {
            ResultVOUtils.error(999, "参数错误");
        }
        return ResultVOUtils.success("更新成功");
    }

    @PostMapping("/udiwms/localBusType/add")
    public BaseResponse addBussinessType(@RequestBody BussinessLocalTypeEntity bussinessTypeEntity,
                                         BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (bussinessTypeEntity != null) {
            bussinessTypeEntity.setAction("ST" + CustomUtil.getId());
            BussinessLocalTypeEntity bussinessLocalTypeEntity = bussinessLocalTypeService.findBTByAction(bussinessTypeEntity.getAction());
            if (bussinessLocalTypeEntity != null) {
                return ResultVOUtils.error(999, "业务类型已存在！");
            } else {
                bussinessLocalTypeService.insertBussinessType(bussinessTypeEntity);
            }

        } else {
            return ResultVOUtils.error(999, "参数错误");
        }
        return ResultVOUtils.success("更新成功");
    }


}
