package com.glxp.api.admin.controller.business;

import com.github.pagehelper.PageInfo;
import com.glxp.api.admin.entity.basic.UdiEntity;
import com.glxp.api.admin.entity.basic.UdiInfoEntity;
import com.glxp.api.admin.entity.business.StockOrderDetailEntity;
import com.glxp.api.admin.entity.info.SystemParamConfigEntity;
import com.glxp.api.admin.req.basic.FilterUdiInfoRequest;
import com.glxp.api.admin.req.business.StockOrderDetailFilterRequest;
import com.glxp.api.admin.req.business.StockOrderIdsRequest;
import com.glxp.api.admin.req.info.SystemParamConfigRequest;
import com.glxp.api.admin.req.inout.DeleteRequest;
import com.glxp.api.admin.res.PageSimpleResponse;
import com.glxp.api.admin.res.basic.UdiRelevanceResponse;
import com.glxp.api.admin.res.business.StockOrderDetailQueryProductResponse;
import com.glxp.api.admin.res.business.StockOrderDetailResponse;
import com.glxp.api.admin.service.basic.UdiInfoService;
import com.glxp.api.admin.service.basic.UdiRelevanceService;
import com.glxp.api.admin.service.business.StockOrderDetailService;
import com.glxp.api.admin.service.business.StockOrderDetailTempService;
import com.glxp.api.admin.service.business.StockQRCodeTextService;
import com.glxp.api.admin.service.info.SystemParamConfigService;
import com.glxp.api.admin.thread.IoTransInoutService;
import com.glxp.api.admin.util.FilterUdiUtils;
import com.glxp.api.common.enums.ResultEnum;
import com.glxp.api.common.res.BaseResponse;
import com.glxp.api.common.util.ResultVOUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@RestController
public class StockOrderDetailController {

    @Resource
    StockOrderDetailService stockOrderDetailService;
    @Resource
    StockOrderDetailTempService stockOrderDetailTempService;
    @Resource
    StockQRCodeTextService stockQRCodeTextService;
    @Resource
    UdiInfoService udiInfoService;
    @Resource
    private UdiRelevanceService udiRelevanceService;

    @Resource
    private IoTransInoutService transInoutService;
    @Autowired
    private SystemParamConfigService systemParamConfigService;

    @GetMapping("/udiwms/stock/order/detail/filter")
    public BaseResponse filterStockOrderDetail(StockOrderDetailFilterRequest stockOrderDetailFilterRequest,
                                               BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<StockOrderDetailEntity> stockOrderDetailEntityList
                = stockOrderDetailService.filterStockOrderDetail(stockOrderDetailFilterRequest);
        PageInfo<StockOrderDetailEntity> pageInfo;
        pageInfo = new PageInfo<>(stockOrderDetailEntityList);
        PageSimpleResponse<StockOrderDetailEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(stockOrderDetailEntityList);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @GetMapping("/udiwms/stock/order/detail/filter2")
    public BaseResponse filterStockOrderDetail2(StockOrderDetailFilterRequest stockOrderDetailFilterRequest,
                                                BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<StockOrderDetailResponse> stockOrderDetailResponseList
                = stockOrderDetailService.filterStockOrderDetail2(stockOrderDetailFilterRequest);
        PageInfo<StockOrderDetailResponse> pageInfo;
        for (StockOrderDetailResponse stockOrderDetailResponse : stockOrderDetailResponseList) {
            stockOrderDetailResponse.setProductName(stockOrderDetailResponse.getCpmctymc());
            stockOrderDetailResponse.setSpec(stockOrderDetailResponse.getGgxh());
        }
        pageInfo = new PageInfo<>(stockOrderDetailResponseList);
        PageSimpleResponse<StockOrderDetailResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(stockOrderDetailResponseList);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @GetMapping("/udiwms/stock/order/detail/temp/filter")
    public BaseResponse filterStockOrderDetailTemp(StockOrderDetailFilterRequest stockOrderDetailFilterRequest,
                                                   BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<StockOrderDetailEntity> stockOrderDetailEntityList
                = stockOrderDetailTempService.filterStockOrderDetailTemp(stockOrderDetailFilterRequest);
        PageInfo<StockOrderDetailEntity> pageInfo;
        pageInfo = new PageInfo<>(stockOrderDetailEntityList);
        PageSimpleResponse<StockOrderDetailEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(stockOrderDetailEntityList);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @GetMapping("/udiwms/stock/order/detail/getStockOrderDetails")
    public BaseResponse getStockOrderDetails(StockOrderDetailFilterRequest stockOrderDetailFilterRequest,
                                             BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<StockOrderDetailEntity> stockOrderDetailEntityList
                = stockOrderDetailService.filterStockOrderDetail(stockOrderDetailFilterRequest);
        PageInfo<StockOrderDetailEntity> pageInfo;
        pageInfo = new PageInfo<>(stockOrderDetailEntityList);
        PageSimpleResponse<StockOrderDetailEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(stockOrderDetailEntityList);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @GetMapping(value = "/udiwms/stock/order/detail")
    public BaseResponse stockOrderDetail(StockOrderDetailFilterRequest stockOrderDetailFilterRequest,
                                         BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (stockOrderDetailFilterRequest.getOrderIdFk() == null || stockOrderDetailFilterRequest.getOrderIdFk().equals("")) {
            stockOrderDetailFilterRequest.setOrderIdFk("1");
        }
        stockOrderDetailFilterRequest.setPage(1);
        stockOrderDetailFilterRequest.setLimit(100);
        List<StockOrderDetailEntity> erpOrderEntities = stockOrderDetailService.filterStockOrderDetail(stockOrderDetailFilterRequest);
        return ResultVOUtils.success(erpOrderEntities);
    }

    @GetMapping("/udiwms/stock/order/detail/uploadCount")
    public BaseResponse uploadCount(@RequestParam("orderId") String orderId, @RequestParam("code") String code) {
        UdiEntity udiEntity = FilterUdiUtils.getUdi(code);
        if (udiEntity == null)
            return ResultVOUtils.error(ResultEnum.DATA_ERROR, "条码错误 1");
        if (StringUtils.isBlank(udiEntity.getUdi()))
            return ResultVOUtils.error(ResultEnum.DATA_ERROR, "条码错误 2");

        UdiInfoEntity udiInfoEntity =
                udiInfoService.findByNameCode(udiEntity.getUdi());
        if (udiInfoEntity == null) {
            return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到该产品");
        }

        StockOrderDetailFilterRequest stockOrderDetailFilterRequest = new StockOrderDetailFilterRequest();
        stockOrderDetailFilterRequest.setOrderIdFk(orderId);
        stockOrderDetailFilterRequest.setProductId(udiEntity.getUdi());
        List<StockOrderDetailEntity> stockOrderDetailEntityList =
                stockOrderDetailService.filterStockOrderDetail(stockOrderDetailFilterRequest);
        if (stockOrderDetailEntityList.size() > 0) {
            SystemParamConfigEntity systemParamConfigEntitySODCountMax =
                    systemParamConfigService.selectByParamKey("stock_order_detail_count_max");

            StockOrderDetailEntity tempStockOrderDetailEntity = stockOrderDetailEntityList.get(0);
            StockOrderDetailEntity stockOrderDetailEntity = new StockOrderDetailEntity();
            stockOrderDetailEntity.setId(tempStockOrderDetailEntity.getId());

            if (systemParamConfigEntitySODCountMax == null ||
                    StringUtils.isNotBlank(systemParamConfigEntitySODCountMax.getParamValue()) &&
                            systemParamConfigEntitySODCountMax.getParamValue().equals("1")) {
                if (Integer.parseInt(tempStockOrderDetailEntity.getCount()) <
                        Integer.parseInt(tempStockOrderDetailEntity.getReCount())) {
                    return ResultVOUtils.error(500, "配货数量超过订单数量");
                }
            }
            stockOrderDetailEntity.setReCount(
                    String.valueOf(Integer.parseInt(tempStockOrderDetailEntity.getReCount()) + 1));
            stockOrderDetailService.updateById(stockOrderDetailEntity);

            return ResultVOUtils.success(orderId);
        }

        return ResultVOUtils.error(ResultEnum.DATA_NOT);
    }

    @GetMapping("/udiwms/stock/order/detail/getInstrument")
    public BaseResponse getStockOrderDetailInstrument(@RequestParam("count") String count, @RequestParam("code") String code) {
        UdiEntity udiEntity = FilterUdiUtils.getUdi(code);
        if (udiEntity == null) ResultVOUtils.error(ResultEnum.DATA_ERROR, "条码错误 1");

        UdiInfoEntity udiInfoEntity =
                udiInfoService.findByNameCode(udiEntity.getUdi());
        if (udiInfoEntity != null) {
            StockOrderDetailEntity stockOrderDetailEntity = new StockOrderDetailEntity();
            stockOrderDetailEntity.setProductId(udiInfoEntity.getNameCode());
            stockOrderDetailEntity.setProductName(udiInfoEntity.getCpmctymc());
            stockOrderDetailEntity.setSpec(udiInfoEntity.getGgxh());
            stockOrderDetailEntity.setBatchNo(udiEntity.getBatchNo());
            stockOrderDetailEntity.setProductDate(udiEntity.getProduceDate());
            stockOrderDetailEntity.setExpireDate(udiEntity.getExpireDate());
            stockOrderDetailEntity.setCount(count);

            return ResultVOUtils.success(stockOrderDetailEntity);
        }

        return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到该产品");
    }

    @PostMapping("/udiwms/stock/order/detail/getInstrumentById")
    public BaseResponse getStockOrderDetailInstrumentById(@RequestBody StockOrderIdsRequest stockOrderIdsRequest) {

        List<StockOrderDetailEntity> stockOrderDetailEntityList = new ArrayList<>();
        List<StockOrderDetailEntity> originDatas = stockOrderIdsRequest.getStockOrderLists();
        for (String id : stockOrderIdsRequest.getIds()) {
            FilterUdiInfoRequest companyProductRelevanceRequest = new FilterUdiInfoRequest();
            companyProductRelevanceRequest.setId(id);
            companyProductRelevanceRequest.setDiType(1);
            List<UdiRelevanceResponse> companyProductRelevanceResponses = udiRelevanceService.filterUdiGp(companyProductRelevanceRequest);

            if (companyProductRelevanceResponses != null && companyProductRelevanceResponses.size() > 0) {
                UdiRelevanceResponse udiInfoEntity = companyProductRelevanceResponses.get(0);
                StockOrderDetailEntity stockOrderDetailEntity = new StockOrderDetailEntity();
                stockOrderDetailEntity.setProductId(udiInfoEntity.getId() + "");
                stockOrderDetailEntity.setProductName(udiInfoEntity.getCpmctymc());
                stockOrderDetailEntity.setSpec(udiInfoEntity.getGgxh());
                stockOrderDetailEntity.setCount(0 + "");
                stockOrderDetailEntity.setReCount(0 + "");
                stockOrderDetailEntity.setYlqxzcrbarmc(udiInfoEntity.getYlqxzcrbarmc());
                stockOrderDetailEntity.setZczbhhzbapzbh(udiInfoEntity.getZczbhhzbapzbh());
                if (stockOrderIdsRequest.getUdiEntity() != null) {
                    UdiEntity udiEntity = stockOrderIdsRequest.getUdiEntity();
                    stockOrderDetailEntity.setBatchNo(udiEntity.getBatchNo());
                    stockOrderDetailEntity.setProductDate(udiEntity.getProduceDate());
                    stockOrderDetailEntity.setExpireDate(udiEntity.getExpireDate());

                    if (originDatas != null && originDatas.size() > 0) {
                        if (!isSameBatch(originDatas, stockOrderDetailEntity)) {
                            stockOrderDetailEntityList.add(stockOrderDetailEntity);
                        }
                    } else {
                        stockOrderDetailEntityList.add(stockOrderDetailEntity);
                    }
                } else
                    stockOrderDetailEntityList.add(stockOrderDetailEntity);
            }
        }
        if (originDatas != null && originDatas.size() > 0) {
            stockOrderDetailEntityList.addAll(originDatas);
        }
        if (stockOrderDetailEntityList.size() == 0) {
            return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到产品");
        }
        return ResultVOUtils.success(stockOrderDetailEntityList);
    }

    public boolean isSameBatch(List<StockOrderDetailEntity> originDatas, StockOrderDetailEntity stockOrderDetailEntity) {
        for (StockOrderDetailEntity temp : originDatas) {
            if ((temp.getBatchNo() != null && temp.getBatchNo().equals(stockOrderDetailEntity.getBatchNo()))
                    && (temp.getProductId().equals(stockOrderDetailEntity.getProductId()))) {
                temp.setCount(Integer.parseInt(temp.getCount()) + Integer.parseInt(stockOrderDetailEntity.getCount()) + "");
                return true;
            }
        }
        return false;
    }

    @GetMapping("/udiwms/stock/order/detail/addFromCode")
    public BaseResponse addStockOrderDetailFromCode(@RequestParam("orderId") String orderId,
                                                    @RequestParam("count") String count,
                                                    @RequestParam("code") String code) {
        UdiEntity udiEntity = FilterUdiUtils.getUdi(code);
        if (udiEntity == null) ResultVOUtils.error(ResultEnum.DATA_ERROR, "条码错误 1");

        UdiInfoEntity udiInfoEntity =
                udiInfoService.findByNameCode(udiEntity.getUdi());
        if (udiInfoEntity != null) {
            StockOrderDetailFilterRequest stockOrderDetailFilterRequest = new StockOrderDetailFilterRequest();
            stockOrderDetailFilterRequest.setOrderIdFk(orderId);
            stockOrderDetailFilterRequest.setProductId(udiEntity.getUdi());
            stockOrderDetailFilterRequest.setBatchNo(udiEntity.getBatchNo());
            stockOrderDetailFilterRequest.setProductDate(udiEntity.getProduceDate());
            stockOrderDetailFilterRequest.setExpireDate(udiEntity.getExpireDate());
            if (stockOrderDetailService.filterStockOrderDetail(stockOrderDetailFilterRequest).size() > 0) {
                return ResultVOUtils.error(ResultEnum.DATA_REPEAT, "已添加");
            }

            StockOrderDetailEntity stockOrderDetailEntity = new StockOrderDetailEntity();
            stockOrderDetailEntity.setOrderIdFk(orderId);
            stockOrderDetailEntity.setProductId(udiInfoEntity.getNameCode());
            stockOrderDetailEntity.setProductName(udiInfoEntity.getCpmctymc());
            stockOrderDetailEntity.setSpec(udiInfoEntity.getGgxh());
            stockOrderDetailEntity.setBatchNo(udiEntity.getBatchNo());
            stockOrderDetailEntity.setProductDate(udiEntity.getProduceDate());
            stockOrderDetailEntity.setExpireDate(udiEntity.getExpireDate());
            stockOrderDetailEntity.setCount(count);
            stockOrderDetailEntity.setReCount(count);
            stockOrderDetailEntity.setSweepCount(0 + "");
            stockOrderDetailEntity.setYlqxzcrbarmc(udiInfoEntity.getYlqxzcrbarmc());
            stockOrderDetailEntity.setZczbhhzbapzbh(udiInfoEntity.getZczbhhzbapzbh());

            stockOrderDetailService.insertStockOrderDetail(stockOrderDetailEntity);

            return ResultVOUtils.success();
        }

        return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到该产品");
    }

    @GetMapping("/udiwms/stock/order/detail/addFromCodeById")
    public BaseResponse addStockOrderDetailFromCodeById(@RequestParam("orderId") String orderId,
                                                        @RequestParam("id") String id) {
        UdiInfoEntity udiInfoEntity =
                udiInfoService.findByNameCode(id);
        if (udiInfoEntity != null) {

            StockOrderDetailEntity stockOrderDetailEntity = new StockOrderDetailEntity();
            stockOrderDetailEntity.setOrderIdFk(orderId);
            stockOrderDetailEntity.setProductId(udiInfoEntity.getNameCode());
            stockOrderDetailEntity.setProductName(udiInfoEntity.getCpmctymc());
            stockOrderDetailEntity.setSpec(udiInfoEntity.getGgxh());
            stockOrderDetailEntity.setBatchNo(udiInfoEntity.getBatchNo());
            stockOrderDetailEntity.setProductDate(udiInfoEntity.getProduceDate());
            stockOrderDetailEntity.setExpireDate(udiInfoEntity.getExpireDate());
            stockOrderDetailEntity.setCount(0 + "");
            stockOrderDetailEntity.setReCount(0 + "");
            stockOrderDetailEntity.setSweepCount(0 + "");
            stockOrderDetailEntity.setYlqxzcrbarmc(udiInfoEntity.getYlqxzcrbarmc());
            stockOrderDetailEntity.setZczbhhzbapzbh(udiInfoEntity.getZczbhhzbapzbh());

            stockOrderDetailService.insertStockOrderDetail(stockOrderDetailEntity);

            return ResultVOUtils.success();
        }

        return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到该产品");
    }

    @GetMapping("/udiwms/stock/order/detail/queryProduct")
    public BaseResponse queryProduct(@RequestParam("code") String code) {
        UdiEntity udiEntity = null;
        if (StringUtils.isNotBlank(code)) {

            if (code.length() > 13) {
                String tStr = code.substring(0, 2);
                if (tStr.contains("MA") || tStr.contains("#") || tStr.contains("01")) {
                    try {
                        udiEntity = FilterUdiUtils.getUdi(code);
                    } catch (Exception e) {

                    }
                }
            }
            StockOrderDetailQueryProductResponse stockOrderDetailQueryProductResponse = new StockOrderDetailQueryProductResponse();
            FilterUdiInfoRequest filterUdiInfoRequest = new FilterUdiInfoRequest();

            if (udiEntity == null) {
                filterUdiInfoRequest.setUnionCode(code);
                stockOrderDetailQueryProductResponse.setUdi(code);
            } else {
                filterUdiInfoRequest.setUnionCode(udiEntity.getUdi());
                BeanUtils.copyProperties(udiEntity, stockOrderDetailQueryProductResponse);
            }
            List<UdiRelevanceResponse> basicInstrumentMaintainRelevanceResponses = null;
            basicInstrumentMaintainRelevanceResponses = udiRelevanceService.filterUdiGp(filterUdiInfoRequest);
            if (basicInstrumentMaintainRelevanceResponses.size() == 1) {
                stockOrderDetailQueryProductResponse.setGetType("1");
                stockOrderDetailQueryProductResponse.setGetId(basicInstrumentMaintainRelevanceResponses.get(0).getId() + "");
            } else if (basicInstrumentMaintainRelevanceResponses.size() > 1) {
                stockOrderDetailQueryProductResponse.setGetType("2");
            } else {
                return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到产品");
            }
            return ResultVOUtils.success(stockOrderDetailQueryProductResponse);
        } else {
            return ResultVOUtils.error(ResultEnum.DATA_NOT, "条码不能为空");
        }

    }

    @GetMapping("/udiwms/stock/order/detail/filterProduct")
    public BaseResponse filterProduct(FilterUdiInfoRequest filterUdiInfoRequest) {

        String nameCode = null;
        UdiEntity udiEntity = null;

        if (filterUdiInfoRequest.getUdiCode() != null && !filterUdiInfoRequest.getUdiCode().isEmpty()) {
            udiEntity = FilterUdiUtils.getUdi(filterUdiInfoRequest.getUdiCode());
        }

        if (udiEntity != null) {
            nameCode = udiEntity.getUdi();
        } else {
            nameCode = filterUdiInfoRequest.getNameCode();
        }

        filterUdiInfoRequest.setNameCode(nameCode);
        filterUdiInfoRequest.setDiType(1);
        List<UdiRelevanceResponse> basicInstrumentMaintainRelevanceResponses = null;
        basicInstrumentMaintainRelevanceResponses = udiRelevanceService.filterUdiGp(filterUdiInfoRequest);

        //todo 为什么要把去掉使用单元
//        if (basicInstrumentMaintainRelevanceResponses != null && basicInstrumentMaintainRelevanceResponses.size() > 0) {
//            for (CompanyProductRelevanceResponse basicInstrumentMaintainRelevanceResponse : basicInstrumentMaintainRelevanceResponses) {
//                if (basicInstrumentMaintainRelevanceResponse.getDiType() == 2 && basicInstrumentMaintainRelevanceResponse.getIsUseDy() != 1) {
//                    basicInstrumentMaintainRelevanceResponse.setNameCode(basicInstrumentMaintainRelevanceResponse.getSjcpbm());
//                }
//            }
//        }

        PageInfo<UdiRelevanceResponse> pageInfo;
        pageInfo = new PageInfo<>(basicInstrumentMaintainRelevanceResponses);
        PageSimpleResponse<UdiRelevanceResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(basicInstrumentMaintainRelevanceResponses);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @GetMapping("/udiwms/stock/order/detail/copy")
    public BaseResponse uploadCount(@RequestParam("id") String id) {
        if (StringUtils.isNotBlank(id)) {
            StockOrderDetailEntity stockOrderDetailEntity = stockOrderDetailService.findOne(id);
            if (stockOrderDetailEntity != null) {
                stockOrderDetailEntity.setId(null);
//                stockOrderDetailEntity.setReCount(0 + "");
                stockOrderDetailService.insertStockOrderDetail(stockOrderDetailEntity);
                return ResultVOUtils.success();
            }
        }
        return ResultVOUtils.error(ResultEnum.DATA_NOT);
    }


    @GetMapping(value = "/udiwms/stock/order/detail/upload")
    public BaseResponse upload(StockOrderDetailFilterRequest stockOrderDetailFilterRequest,
                               BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (StringUtils.isNotBlank(stockOrderDetailFilterRequest.getId())) {
            if (StringUtils.isBlank(stockOrderDetailFilterRequest.getCount()) ||
                    StringUtils.isBlank(stockOrderDetailFilterRequest.getReCount())) {
                return ResultVOUtils.error(500, "获取数量失败");
            }
            SystemParamConfigEntity systemParamConfigEntitySODCountMax = systemParamConfigService.selectByParamKey("stock_order_detail_count_max");
            if (systemParamConfigEntitySODCountMax == null) return ResultVOUtils.error(500, "获取设置失败");

            if (StringUtils.isNotBlank(systemParamConfigEntitySODCountMax.getParamValue()) &&
                    systemParamConfigEntitySODCountMax.getParamValue().equals("1")) {
                if (Integer.parseInt(stockOrderDetailFilterRequest.getCount()) <
                        Integer.parseInt(stockOrderDetailFilterRequest.getReCount())) {
                    return ResultVOUtils.error(500, "数量超过订单数量");
                }
            }

            StockOrderDetailEntity stockOrderDetailEntity = new StockOrderDetailEntity();
            BeanUtils.copyProperties(stockOrderDetailFilterRequest, stockOrderDetailEntity);
            boolean b = stockOrderDetailService.updateById(stockOrderDetailEntity);
            if (b) {
                return ResultVOUtils.success();
            }
        }
        return ResultVOUtils.error(500, "修改失败");
    }

    @PostMapping("/udiwms/stock/order/detail/delete")
    public BaseResponse delete(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        boolean b = stockOrderDetailService.deleteById(deleteRequest.getId());
        if (b) {
            return ResultVOUtils.success("删除成功");
        } else {
            return ResultVOUtils.error(500, "删除失败");
        }
    }

    @PostMapping("/udiwms/stock/order/detail/temp/delete")
    public BaseResponse deleteTemp(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        boolean b = stockOrderDetailTempService.deleteById(deleteRequest.getId());
        if (b) {
            return ResultVOUtils.success("删除成功");
        } else {
            return ResultVOUtils.error(500, "删除失败");
        }
    }
}
