package com.glxp.api.admin.controller.inventory;

import com.glxp.api.admin.entity.inventory.InvWarehouseEntity;
import com.glxp.api.admin.req.inout.DeleteRequest;
import com.glxp.api.admin.req.inventory.FilterInvWarehouseRequest;
import com.glxp.api.admin.res.inventory.InvWarehouseResponse;
import com.glxp.api.admin.service.inventory.InvWarehouseService;
import com.glxp.api.common.enums.ResultEnum;
import com.glxp.api.common.res.BaseResponse;
import com.glxp.api.common.util.ResultVOUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
public class InvWarehouseController {

    @Resource
    InvWarehouseService invWarehouseService;

    @GetMapping("spms/inv/warehouse/filter")
    public BaseResponse filterInvWarehouse(FilterInvWarehouseRequest filterInvWarehouseRequest) {
        List<InvWarehouseEntity> invWarehouseEntities = invWarehouseService.filterInvWarehouse(filterInvWarehouseRequest);
        List<InvWarehouseResponse> merge = merge(invWarehouseEntities, 0);

        Map<String, Object> restMap = new HashMap<>();
        restMap.put("list", merge);
        return ResultVOUtils.success(restMap);
    }

    @GetMapping("spms/inv/warehouse/filterAll")
    public BaseResponse filterAllInvWarehouse(FilterInvWarehouseRequest filterInvWarehouseRequest) {
        filterInvWarehouseRequest.setPid(0);
        List<InvWarehouseEntity> invWarehouseEntities = invWarehouseService.filterInvWarehouse(filterInvWarehouseRequest);
        return ResultVOUtils.success(invWarehouseEntities);
    }

    public List<InvWarehouseResponse> merge(List<InvWarehouseEntity> invWarehouseEntities,
                                            Integer pid) {
        List<InvWarehouseResponse> invWarehouseResponses = new ArrayList<>();
        for (InvWarehouseEntity invWarehouseEntity : invWarehouseEntities) {
            InvWarehouseResponse invWarehouseResponse = new InvWarehouseResponse();
            BeanUtils.copyProperties(invWarehouseEntity, invWarehouseResponse);
            if (pid.equals(invWarehouseEntity.getPid())) {
                invWarehouseResponse.setChildren(merge(invWarehouseEntities, invWarehouseEntity.getId()));
                invWarehouseResponses.add(invWarehouseResponse);
            }
        }
        return invWarehouseResponses;
    }


    @PostMapping("/spms/inv/warehouse/save")
    public BaseResponse save(@RequestBody @Valid InvWarehouseEntity invWarehouseEntity,
                             BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }

        if (invWarehouseEntity.getPid() == null) {
            invWarehouseEntity.setPid(0); // 默认设置
        }

        boolean b = invWarehouseService.insertInvWarehouse(invWarehouseEntity);
        if (!b) {
            return ResultVOUtils.error(ResultEnum.NOT_NETWORK);
        }

        return ResultVOUtils.success("添加成功！");
    }

    @PostMapping("/spms/inv/warehouse/edit")
    public BaseResponse edit(@RequestBody @Valid InvWarehouseEntity invWarehouseEntity,
                             BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        if (invWarehouseEntity.getId() == null) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL);
        }
        invWarehouseEntity.setPid(null); // 不能修改父级 pid
        boolean b = invWarehouseService.updateInvWarehouse(invWarehouseEntity);
        if (!b) {
            return ResultVOUtils.error(ResultEnum.NOT_NETWORK);
        }

        return ResultVOUtils.success();
    }

    @PostMapping("/spms/inv/warehouse/delete")
    public BaseResponse delete(@RequestBody DeleteRequest deleteRequest) {

        if (deleteRequest.getId() == null) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL);
        }
        boolean b = invWarehouseService.deleteById(deleteRequest.getId());
        if (!b) {
            return ResultVOUtils.error(ResultEnum.NOT_NETWORK);
        }
        return ResultVOUtils.success();
    }


}
