package com.glxp.api.admin.thread;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.io.file.FileWriter;
import cn.hutool.json.JSONUtil;
import com.glxp.api.admin.constant.BasicProcessStatus;
import com.glxp.api.admin.dao.basic.UdiInfoDao;
import com.glxp.api.admin.dao.basic.UdiRelevanceDao;
import com.glxp.api.admin.entity.basic.*;
import com.glxp.api.admin.req.basic.BasicUnitMaintainFilterRequest;
import com.glxp.api.admin.req.basic.CorpsExportRequest;
import com.glxp.api.admin.req.basic.FilterUdiInfoRequest;
import com.glxp.api.admin.req.basic.UdiInfoExportRequest;
import com.glxp.api.admin.res.basic.UdiRelevanceExportJsonResponse;
import com.glxp.api.admin.res.basic.UdiRelevanceResponse;
import com.glxp.api.admin.service.basic.BasicUnitMaintainService;
import com.glxp.api.admin.service.basic.CorpExportLogService;
import com.glxp.api.admin.service.basic.UdiInfoExportLogService;
import com.glxp.api.admin.service.basic.UdiRelevanceService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class BasicGenJsonService {

    @Resource
    CorpExportLogService corpExportLogService;
    @Resource
    BasicUnitMaintainService basicUnitMaintainService;
    @Resource
    UdiInfoExportLogService udiInfoExportLogService;
    @Resource
    UdiRelevanceService udiRelevanceService;
    @Resource
    UdiRelevanceDao udiRelevanceDao;
    @Resource
    UdiInfoDao udiInfoDao;


    public void exportCorp(String genKey, CorpsExportRequest corpsExportRequest) {
        CorpExportLogEntity corpExportLogEntity = corpExportLogService.selectByGenKey(genKey);
        List<BasicUnitMaintainEntity> exportData = new ArrayList<>();
        if (corpsExportRequest.getIds() != null && corpsExportRequest.getIds().size() > 0) {
            List<Integer> ids = corpsExportRequest.getIds();
            ids.forEach(id -> {
                BasicUnitMaintainFilterRequest request = new BasicUnitMaintainFilterRequest();
                request.setId(id);
                List<BasicUnitMaintainEntity> basicUnitMaintainEntities = basicUnitMaintainService.filterList(request);
                exportData.addAll(basicUnitMaintainEntities);
            });
        } else { //一键导出
            BasicUnitMaintainFilterRequest filterRequest = new BasicUnitMaintainFilterRequest();
            BeanUtils.copyProperties(corpsExportRequest, filterRequest);
            filterRequest.setPage(null);
            List<BasicUnitMaintainEntity> basicUnitMaintainEntities = basicUnitMaintainService.filterList(filterRequest);
            exportData.addAll(basicUnitMaintainEntities);
        }

        FileWriter writer = new FileWriter(corpExportLogEntity.getFilePath());
        writer.write(JSONUtil.toJsonStr(exportData));
        corpExportLogEntity.setStatus(BasicProcessStatus.UDIINFO_IMPORT_SUCCESS);
        corpExportLogService.updateCorpExportLog(corpExportLogEntity);
    }

    /**
     * 导出json格式医疗器械信息
     *
     * @param genKey
     * @param udiInfoExportRequest
     */
    @Async
    public void exportUdiInfoJson(String genKey, UdiInfoExportRequest udiInfoExportRequest) {
        UdiInfoExportLogEntity udiInfoExportLogEntity = udiInfoExportLogService.selectByGenKey(genKey);
        UdiRelevanceExportJsonResponse exportData = new UdiRelevanceExportJsonResponse();
        //选中导出
        if (CollUtil.isNotEmpty(udiInfoExportRequest.getUuids())) {
            List<String> uuids = udiInfoExportRequest.getUuids();
            uuids.forEach(uuid -> {
                FilterUdiInfoRequest filterUdiInfoRequest = new FilterUdiInfoRequest();
                filterUdiInfoRequest.setUuid(uuid);
                List<UdiRelevanceResponse> udiRelevanceResponses = udiRelevanceService.filterUdiRelevance(filterUdiInfoRequest);
                if (CollUtil.isNotEmpty(udiRelevanceResponses)) {
                    parseUdiRelevanceResponses(exportData, udiRelevanceResponses);
                }
            });
        } else {
            //一键导出
            FilterUdiInfoRequest filterUdiInfoRequest = new FilterUdiInfoRequest();
            BeanUtil.copyProperties(udiInfoExportRequest, filterUdiInfoRequest);
            filterUdiInfoRequest.setPage(null);
            List<UdiRelevanceResponse> data = udiRelevanceService.filterUdiRelevance(filterUdiInfoRequest);
            if (CollUtil.isNotEmpty(data)) {
                parseUdiRelevanceResponses(exportData, data);
            }
        }

        File file = new File(udiInfoExportLogEntity.getFilePath());
        if (!file.exists()) {
            try {
                file.createNewFile();
            } catch (Exception e) {
                log.error("导出医疗器械信息异常", e);
            }
        }
        FileWriter writer = new FileWriter(file);
        writer.write(JSONUtil.toJsonStr(exportData));
        udiInfoExportLogEntity.setStatus(BasicProcessStatus.UDIINFO_IMPORT_SUCCESS);
        udiInfoExportLogService.updateUdiInfoExportLog(udiInfoExportLogEntity);
    }


    /**
     * 解析医疗器械信息查询结果，封装完整数据
     *
     * @param exportData
     * @param udiRelevanceResponses
     */
    private void parseUdiRelevanceResponses(UdiRelevanceExportJsonResponse exportData, List<UdiRelevanceResponse> udiRelevanceResponses) {
        List<String> uuids = new ArrayList<>(udiRelevanceResponses.size());
        udiRelevanceResponses.forEach(udi -> {
            uuids.add(udi.getUuid());
        });
        List<UdiInfoEntity> udiInfoEntities = udiInfoDao.batchSelectByUuid(uuids);
        List<UdiRelevanceEntity> udiRelevanceEntities = udiRelevanceDao.batchSelectByUuid(uuids);
        List<UdiInfoEntity> udiInfo = exportData.getUdiInfoEntities();
        List<UdiRelevanceEntity> udiRelevance = exportData.getUdiRelevanceEntities();
        udiInfo.addAll(udiInfoEntities);
        udiRelevance.addAll(udiRelevanceEntities);
        exportData.setUdiInfoEntities(udiInfo);
        exportData.setUdiRelevanceEntities(udiRelevance);
    }
}
