package com.glxp.api.admin.util;

import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.glxp.api.admin.entity.inout.IOOrderStatusEntity;
import com.glxp.api.admin.httpclient.UHttpClient;
import com.glxp.api.admin.req.inout.OrderStatusFilterRequest;
import com.glxp.api.admin.res.PageSimpleResponse;
import com.glxp.api.admin.res.inout.DlOrderResponse;
import com.glxp.api.common.res.BaseResponse;
import com.glxp.api.common.util.ResultVOUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class SpGetHttp {

    @Value("${SPSYNC_IP}")
    private String spsSyncUrl;

    public BaseResponse<PageSimpleResponse<IOOrderStatusEntity>> getOrderStatus() {
        Map<String, Object> paramMap = new HashMap<>(16);
        paramMap.put("status", 1);
        String response = UHttpClient.mipsGet(spsSyncUrl + "/spms/inout/order/status", paramMap);
        try {
            BaseResponse<PageSimpleResponse<IOOrderStatusEntity>> data =
                    JSONObject.parseObject(response, new TypeReference<BaseResponse<PageSimpleResponse<IOOrderStatusEntity>>>() {
                    });
            return data;

        } catch (Exception e) {
            e.printStackTrace();
            return ResultVOUtils.error(500, "下载失败！");
        }
    }


    public BaseResponse<List<DlOrderResponse>> getOrders(String orderId) {
        Map<String, Object> paramMap = new HashMap<>(16);
        paramMap.put("orderId", orderId);
        String response = UHttpClient.mipsGet(spsSyncUrl + "/spms/inout/order/dlByStatus", paramMap);
        try {
            BaseResponse<List<DlOrderResponse>> data =
                    JSONObject.parseObject(response, new TypeReference<BaseResponse<List<DlOrderResponse>>>() {
                    });
            return data;
        } catch (Exception e) {
            e.printStackTrace();
            return ResultVOUtils.error(500, "下载失败！");
        }
    }


    public BaseResponse<String> postOrder(String orderId) {
        OrderStatusFilterRequest orderStatusFilterRequest = new OrderStatusFilterRequest();
        orderStatusFilterRequest.setOrderId(orderId);
        orderStatusFilterRequest.setStatus(2);
        String result = UHttpClient.postJson(spsSyncUrl + "/spms/inout/order/updateStatus", orderStatusFilterRequest);
        BaseResponse<String> response =
                JSONObject.parseObject(result, new TypeReference<BaseResponse<String>>() {
                });
        return response;
    }

}
